#ifndef LINT
static char *rcsid="$Id: epinfo.c,v 2.4 1998/10/18 13:18:27 crosser Exp $";
#endif

/*
	Copyright (c) 1997,1998 Eugene G. Crosser
	Copyright (c) 1998 Bruce D. Lightner (DOS/Windows support)

	You may distribute and/or use for any purpose modified or unmodified
	copies of this software if you preserve the copyright notice above.

	THIS SOFTWARE IS PROVIDED AS IS AND COME WITH NO WARRANTY OF ANY
	KIND, EITHER EXPRESSED OR IMPLIED.  IN NO EVENT WILL THE
	COPYRIGHT HOLDER BE LIABLE FOR ANY DAMAGES RESULTING FROM THE
	USE OF THIS SOFTWARE.
*/

/*
	$Log: epinfo.c,v $
	Revision 2.4  1998/10/18 13:18:27  crosser
	Put RCS logs and I.D. into the source

	Revision 2.3  1998/02/13 23:02:40  crosser
	use proper open mode on DOS
	
	Revision 2.2  1998/02/08 19:58:38  crosser
	Support low memory: chunked saving etc.
	
	Revision 2.1  1998/01/18 02:16:45  crosser
	DOS support
	
	Revision 2.0  1998/01/02 19:20:11  crosser
	Added support for Win32
	
	Revision 1.2  1997/12/24 00:19:13  crosser
	Do not check vendor identifier
	
	Revision 1.1  1997/08/17 08:59:54  crosser
	Initial revision
	
*/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <string.h>
#include "jscan.h"

#ifdef UNIX
#define READMODE "r"
#else
#define READMODE "rb"
#endif

int main(int argc,char *argv[]) {
	FILE *fp;
	struct stat st;
	unsigned char *buf,*res,*key=NULL,*p,*q;
	off_t bufsize,ressize;
	int i;

	if (argc == 3) {
		key=argv[2];
	} else if (argc != 2) {
		fprintf(stderr,"usage: %s <filename> [<keyword>]\n",argv[0]);
		return -1;
	}

	if ((fp=fopen(argv[1],READMODE)) == NULL) {
		perror(argv[1]);
		return -1;
	}

	if (fstat(fileno(fp),&st)) {
		perror(argv[1]);
		return -1;
	}

#ifdef LOWMEMORY
	if (st.st_size > MAXJPREFIX)
		bufsize=MAXJPREFIX;
	else
#endif
		bufsize=st.st_size;
	buf=malloc(bufsize);
	if (buf == NULL) {
		perror("malloc");
		return -1;
	}

	if (fread(buf,bufsize,1,fp) != 1) {
		perror("read");
		free(buf);
		fclose(fp);
		return -1;
	}
	fclose(fp);

	res=buf;
	ressize=bufsize;
	if (jscan(&res,&ressize)) {
		fprintf(stderr,"No camera-specific information in the file\n");
		free(buf);
		return -1;
	}

	if (key) {
		p=jsearch(key,res,ressize);
		if (p == NULL) {
			fprintf(stderr,"Key not found\n");
			free(buf);
			return -1;
		}
		if ((q=strchr(p,'\n'))) *q='\0';
		printf("%s\n",p);
	} else {
		for (i=0;i<ressize;i++)
			printf("%c",res[i]);
		printf("\n");
	}

	free(buf);
	return 0;
}
